Documentation
¶
Overview ¶
Weblang language implementation main package
Index ¶
- Constants
- type Config
- type ConfigItem
- type Directories
- type EventHandler
- type Project
- type VM
- func (vm *VM) BeforeStaticFilesInit(event EventHandler)
- func (vm *VM) DefineFunc(className string, methodName string, handler base.FunctionHandler)
- func (vm *VM) GitPreperWebHook(gitUrl string, gitUser string, gitToken string, gitLocalDir string, ...) error
- func (vm *VM) InitVM(configFile string)
- func (vm *VM) InstallCmsUser(userName, password string) error
- func (vm *VM) StartServer() error
Constants ¶
const Version string = "v0.8.1"
Weblang version string
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶ added in v0.6.24
type Config struct {
Version string `yaml:"version"`
Project Project `yaml:"project"`
Config []ConfigItem `yaml:"config"`
}
Yaml main struct
type ConfigItem ¶ added in v0.6.24
Yaml config array item
type Directories ¶ added in v0.6.24
type Directories struct {
SourceDir string `yaml:"sourceDir"`
BytecodeDir string `yaml:"bytecodeDir"`
}
Yaml directories struct
type EventHandler ¶ added in v0.4.8
type EventHandler func(e interface{}) error
EventHandler function for server and VM events
type Project ¶ added in v0.6.24
type Project struct {
Name string `yaml:"name"`
Version string `yaml:"version"`
Directories Directories `yaml:"directories"`
}
Yaml project struct
type VM ¶
type VM struct {
// contains filtered or unexported fields
}
Main VM struct
func (*VM) BeforeStaticFilesInit ¶ added in v0.4.8
func (vm *VM) BeforeStaticFilesInit(event EventHandler)
Event before static files server handler initialization
func (*VM) DefineFunc ¶ added in v0.2.4
func (vm *VM) DefineFunc(className string, methodName string, handler base.FunctionHandler)
Set handler to specific class method (works with external methods only)
func (*VM) GitPreperWebHook ¶ added in v0.6.25
func (vm *VM) GitPreperWebHook(gitUrl string, gitUser string, gitToken string, gitLocalDir string, gitWebHook string) error
Clone git repository to gitLocalDir and listen request from webHook url for git changes
func (*VM) InitVM ¶
Weblang now require configuration file weblang.yml in your project directory to work correctly. Initialize VM environment. Please provide correct configFile (config file name).
func (*VM) InstallCmsUser ¶ added in v0.6.28
Install CMS to database and set userName and password
func (*VM) StartServer ¶ added in v0.3.16
Starts server process in VM environment
Directories
¶
| Path | Synopsis |
|---|---|
|
Weblang VM environment base struct types such as Function, MmemoryMap, Class and Object.
|
Weblang VM environment base struct types such as Function, MmemoryMap, Class and Object. |
|
Weblang bytecode main package
|
Weblang bytecode main package |
|
class
Class struct of Weblang bytecode
|
Class struct of Weblang bytecode |
|
class/attribute
Class attributes struct of Weblang bytcode
|
Class attributes struct of Weblang bytcode |
|
generator
Weblang bytecode generator package
|
Weblang bytecode generator package |
|
instructionset
Instuctionset struct of Weblang bytecode files
|
Instuctionset struct of Weblang bytecode files |
|
loader
bytcode loader package
|
bytcode loader package |
|
Package for subcommandss implementations
|
Package for subcommandss implementations |
|
run
Run subcommand implementation
|
Run subcommand implementation |
|
version
Version subcommand implementation
|
Version subcommand implementation |
|
Http handler controller
|
Http handler controller |
|
Weblang core packages for Weblang VM runtime environment
|
Weblang core packages for Weblang VM runtime environment |
|
cms
Weblang Content Managment System
|
Weblang Content Managment System |
|
firewall
Weblang firewall package.
|
Weblang firewall package. |
|
runtime
This is core package for Weblang language.
|
This is core package for Weblang language. |
|
server
Server implemantation for use in Weblang VM runtime environment
|
Server implemantation for use in Weblang VM runtime environment |
|
Weblang language parser
|
Weblang language parser |