Documentation
¶
Overview ¶
Weblang language implementation main package
Index ¶
Constants ¶
const Version string = "v0.4.18"
Weblang version string
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type EventHandler ¶ added in v0.4.8
type EventHandler func(e interface{}) error
EventHandler function for server and VM events
type VM ¶
type VM struct {
// contains filtered or unexported fields
}
Main VM struct
func (*VM) BeforeStaticFilesInit ¶ added in v0.4.8
func (vm *VM) BeforeStaticFilesInit(event EventHandler)
Event before static files server handler initialization
func (*VM) DefineFunc ¶ added in v0.2.4
func (vm *VM) DefineFunc(className string, methodName string, handler base.FunctionHandler)
Set handler to specific class method (works with external methods only)
func (*VM) InitVM ¶
Initialize VM environment. Please provide correct sourceDir (directory of Web language source files) and byteCodeDir (directory for bytecode files)
func (*VM) StartServer ¶ added in v0.3.16
Starts server process in VM environment
Directories
¶
| Path | Synopsis |
|---|---|
|
Weblang VM environment base struct types such as Function, MmemoryMap, Class and Object.
|
Weblang VM environment base struct types such as Function, MmemoryMap, Class and Object. |
|
Weblang bytecode main package
|
Weblang bytecode main package |
|
class
Class struct of Weblang bytecode
|
Class struct of Weblang bytecode |
|
class/attribute
Class attributes struct of Weblang bytcode
|
Class attributes struct of Weblang bytcode |
|
generator
Weblang bytecode generator package
|
Weblang bytecode generator package |
|
instructionset
Instuctionset struct of Weblang bytecode files
|
Instuctionset struct of Weblang bytecode files |
|
Weblang core packages for Weblang VM runtime environment
|
Weblang core packages for Weblang VM runtime environment |
|
cms
Weblang Content Managment System
|
Weblang Content Managment System |
|
firewall
Weblang firewall package.
|
Weblang firewall package. |
|
runtime
This is core package for Weblang language.
|
This is core package for Weblang language. |
|
server
Server implemantation for use in Weblang VM runtime environment
|
Server implemantation for use in Weblang VM runtime environment |
Click to show internal directories.
Click to hide internal directories.